//---------------------------------------------------------------------------

#include <vcl.h>
#include <gl.h>
#include <fstream.h>
#pragma hdrstop

#include "Main.h"
#include "AboutBox.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TMainForm *MainForm;
//---------------------------------------------------------------------------
__fastcall TMainForm::TMainForm(TComponent* Owner)
    : TForm(Owner)
{
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::SetDCPixelFormat(HDC hdc)
{
	static PIXELFORMATDESCRIPTOR pfd =
	{
		sizeof(PIXELFORMATDESCRIPTOR),          // sizeof this structure
		1,                                      // version number
		PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL
		| PFD_DOUBLEBUFFER,                     // flags
		PFD_TYPE_RGBA,                          // RGBA pixel values
		16,                                     // 16-bit color
		0, 0, 0, 0, 0, 0,                       // don't care about these
		0, 0,                                   // no alpha buffer
		0, 0, 0, 0, 0,                          // no accumulation buffer
		16,                                     // 16-bit depth buffer
		0,                                      // no stencil buffer
		0,                                      // no auxiliary buffers
		PFD_MAIN_PLANE,                         // layer type
		0,                                      // reserved(must be 0)
		0, 0, 0                                 // no layer masks
	};
	int pixelFormat = ChoosePixelFormat(hdc, &pfd);
	SetPixelFormat(hdc, pixelFormat, &pfd);
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::FormCreate(TObject *Sender)
{
    HDC hDC = GetDC(Handle);
    SetDCPixelFormat(hDC);
    HGLRC hglrc = wglCreateContext(hDC);
    if (!hglrc)
    {
        Application->MessageBox("Unable to create OpenGL rendering context",
            Application->Title.c_str(), MB_OK | MB_ICONSTOP);
        TerminateProcess((void *)0xFFFFFFFF, -1);
    }
    wglMakeCurrent(hDC, hglrc);
    GLVendor->Text = (char *)glGetString(GL_VENDOR);
    GLRenderer->Text = (char *)glGetString(GL_RENDERER);
    GLVersion->Text = (char *)glGetString(GL_VERSION);
    char *ext = (char *)glGetString(GL_EXTENSIONS), *p;
    char t[256];
    do
    {
        p = strchr(ext, ' ');
        if (p)
        {
            memcpy(t, ext, p - ext);
            t[p - ext] = 0;
            ExtList->Items->Add(t);
            p++;
        }
        ext = p;
    } while (p);
    ExtList->ItemIndex = 0;
    wglMakeCurrent(NULL, NULL);
    wglDeleteContext(hglrc);
    ReleaseDC(Handle, hDC);
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::CloseBtnClick(TObject *Sender)
{
    Close();    
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::SaveBtnClick(TObject *Sender)
{
    if (!SaveDialog->Execute()) return;
    ofstream out(SaveDialog->FileName.c_str());
    if (!out)
    {
        Application->MessageBox("Unable to create specified file",
            Application->Title.c_str(), MB_OK | MB_ICONSTOP);
        return;
    }
    out << Label1->Caption.c_str() << ' ' << GLVendor->Text.c_str() << '\n';
    out << Label2->Caption.c_str() << ' ' << GLRenderer->Text.c_str() << '\n';
    out << Label3->Caption.c_str() << ' ' << GLVersion->Text.c_str() << '\n';
    out << GroupBox1->Caption.c_str() << ":\n";
    int i = 0, k = ExtList->Items->Count;
    for (; i < k; i++)
        out << ExtList->Items->Strings[i].c_str() << '\n';
    out.close();
}
//---------------------------------------------------------------------------
void __fastcall TMainForm::AboutBtnClick(TObject *Sender)
{
    AboutBoxDlg->ShowModal();
}
//---------------------------------------------------------------------------

